staging: et131x: Converting et1310_pm.c function and local names from CamelCase

Tested on an ET-131x device.

Signed-off-by: Mark Einon <mark.einon@gmail.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
diff --git a/drivers/staging/et131x/et1310_phy.c b/drivers/staging/et131x/et1310_phy.c
index d53656b..72892e0 100644
--- a/drivers/staging/et131x/et1310_phy.c
+++ b/drivers/staging/et131x/et1310_phy.c
@@ -811,7 +811,7 @@
 			 * plugged back in
 			 */
 			if (etdev->RegistryPhyComa == 1)
-				EnablePhyComa(etdev);
+				et1310_enable_phy_coma(etdev);
 		}
 	}
 
diff --git a/drivers/staging/et131x/et131x.h b/drivers/staging/et131x/et131x.h
index c4f9032..240305e 100644
--- a/drivers/staging/et131x/et131x.h
+++ b/drivers/staging/et131x/et131x.h
@@ -85,11 +85,11 @@
 /* et131x_netdev.c */
 struct net_device *et131x_device_alloc(void);
 
-/* et131x_pm.c */
-void EnablePhyComa(struct et131x_adapter *adapter);
-void DisablePhyComa(struct et131x_adapter *adapter);
+/* et1310_pm.c */
+void et1310_enable_phy_coma(struct et131x_adapter *adapter);
+void et1310_disable_phy_coma(struct et131x_adapter *adapter);
 
-/* et131x_phy.c */
+/* et1310_phy.c */
 void et1310_phy_init(struct et131x_adapter *adapter);
 void et1310_phy_reset(struct et131x_adapter *adapter);
 void et1310_phy_power_down(struct et131x_adapter *adapter, bool down);
diff --git a/drivers/staging/et131x/et131x_initpci.c b/drivers/staging/et131x/et131x_initpci.c
index 9b01f22..c39f5f0 100644
--- a/drivers/staging/et131x/et131x_initpci.c
+++ b/drivers/staging/et131x/et131x_initpci.c
@@ -288,7 +288,7 @@
 				 *  interrupt'. How to do that under Linux?
 				 */
 				et131x_enable_interrupts(etdev);
-				EnablePhyComa(etdev);
+				et1310_enable_phy_coma(etdev);
 			}
 		}
 	}
diff --git a/drivers/staging/et131x/et131x_isr.c b/drivers/staging/et131x/et131x_isr.c
index 0a810cc..dd952f0 100644
--- a/drivers/staging/et131x/et131x_isr.c
+++ b/drivers/staging/et131x/et131x_isr.c
@@ -379,7 +379,7 @@
 				 * so, disable it because we will not be able
 				 * to read PHY values until we are out.
 				 */
-				DisablePhyComa(etdev);
+				et1310_disable_phy_coma(etdev);
 			}
 
 			/* Read the PHY ISR to clear the reason for the
diff --git a/drivers/staging/et131x/et1310_pm.c b/drivers/staging/et131x/et1310_pm.c
index 29d4d66..1bfcc67 100644
--- a/drivers/staging/et131x/et1310_pm.c
+++ b/drivers/staging/et131x/et1310_pm.c
@@ -87,7 +87,7 @@
 #include "et131x.h"
 
 /**
  * EnablePhyComa - called when network cable is unplugged
  * @etdev: pointer to our adapter structure
  *
  * driver receive an phy status change interrupt while in D0 and check that
@@ -106,7 +106,7 @@
  *       indicating linkup status, call the MPDisablePhyComa routine to
  *             restore JAGCore and gigE PHY
  */
-void EnablePhyComa(struct et131x_adapter *etdev)
+void et1310_enable_phy_coma(struct et131x_adapter *etdev)
 {
 	unsigned long flags;
 	u32 pmcsr;
@@ -136,10 +136,10 @@
 }
 
 /**
  * DisablePhyComa - Disable the Phy Coma Mode
  * @etdev: pointer to our adapter structure
  */
-void DisablePhyComa(struct et131x_adapter *etdev)
+void et1310_disable_phy_coma(struct et131x_adapter *etdev)
 {
 	u32 pmcsr;
 
@@ -87,7 +87,7 @@
 
 /**
- * EnablePhyComa - called when network cable is unplugged
+ * et1310_enable_phy_coma - called when network cable is unplugged
  * @etdev: pointer to our adapter structure
  *
@@ -136,10 +136,10 @@
 
 /**
- * DisablePhyComa - Disable the Phy Coma Mode
+ * et1310_disable_phy_coma - Disable the Phy Coma Mode
  * @etdev: pointer to our adapter structure
  */